translate.filters.pofilter

Package translate :: Package filters :: Module pofilter |
[hide private]
[frames] | no frames]

# Module pofilter

source code

Perform quality checks on Gettext PO, XLIFF and TMX localization files

Snippet files whenever a test fails. These can be examined, corrected and merged back into the originals using pomerge

See: http://translate.sourceforge.net/wiki/toolkit/pofilter for examples and usage instructions and http://translate.sourceforge.net/wiki/toolkit/pofilter_tests for full descriptions of all tests

Classes | [hide private]
| pocheckfilter
| FilterOptionParser a specialized Option Parser for filter tools...

Functions | [hide private]
build_checkerconfig(options) Prepare the checker config from the given options. | source code
runfilter(inputfile, outputfile, templatefile, checkfilter=None) reads in inputfile, filters using checkfilter, writes to outputfile | source code
cmdlineparser() | source code
main() | source code

Imports: factory, poheader, checks, autocorrect, optrecurse, os

Function Details | [hide private]

### build_checkerconfig(options) | source code
Prepare the checker config from the given options. This is mainly factored out for the sake of unit tests.